xkcdpassword
=

A simple, pure Python, Xkcd-style password generator. 

e.g: "correct horse battery staple"

When invoked, this package will generate a short list of unique words, perhaps to a specified number, and then return them on sys.std.out. The user can also specify to remove spaces so the output can be easily copy-pasted or piped. The word list is customizable (words.txt), and already curated for length.

### Prerequisites

Python 2.7
Pyperclip

### Installing

`sudo pip install xkcdpassword`

### Using

`$ xkcdpassword` -> `correct horse battery staple`

`$ xkcdpassword -ns` -> `correcthorsebatterystaple`

`$ xkcdpassword 3` -> `correct horse battery`

`$ xkcdpassword -ns 6` -> `correcthorsebatterystaplethingexplainer`

`$ xkcdpassword -h` -> Syntax help

### Authors

* **Doug Walter** - **dougwritescode@gmail.com**

### License

This project is licensed under the MIT License - see the [LICENSE.txt](LICENSE.txt) file for details

## Acknowledgments

* Randall Patrick Munroe, the ruler of the geek pantheon.

